Gentile *{{ data.name | safe }}*,

grazie per averci contattato. In data {{ created | safe }} hai inviato il seguente messaggio:

**{{ data.message | safe }}**

Sarai ricontattato al più presto da uno dei nostri consulenti.

Distinti Saluti,

*Team*